@@ -20,10 +20,9 @@
 #include <kopenwithdialog.h>
 
 #include <KLocalizedString>
-#include <KGlobal>
 #include <KConfigGroup>
-
-#include <KUrl>
+#include <KSharedConfig>
+#include <QUrl>
 
 // for chmod:
 #include <sys/types.h>
@@ -79,7 +78,7 @@ void CfgEmailClient::configChanged()
 
 void CfgEmailClient::selectEmailClient()
 {
-    KUrl::List urlList;
+    QList<QUrl> urlList;
     KOpenWithDialog dlg(urlList, i18n("Select preferred email client:"), QString(), this);
     // hide "Do not &close when command exits" here, we don't need it for a mail client
     dlg.hideNoCloseOnExit();
