@@ -23,10 +23,7 @@
 
 #include <config-X11.h>
 
-#include <klocale.h>
-#include <kglobal.h>
 #include <kconfig.h>
-#include <kdemacros.h>
 #include <QFile>
 
 #include "mouse.h"
