@@ -16,15 +16,17 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#include <kdebug.h>
-#include <QApplication>
-#include <qtest_kde.h>
+#include <QtTest/QtTest>
 
 #include "../xkb_rules.h"
 
 #include <qdom.h>
 #include <qxml.h>
 
+
+Q_LOGGING_CATEGORY(KCM_KEYBOARD, "kcm_keyboard")
+
+
 static const Rules::ExtrasFlag readExtras = Rules::NO_EXTRAS;
 
 class RulesTest : public QObject
@@ -189,7 +191,7 @@ private Q_SLOTS:
 
     	QFile file("base2.xml");
         if( ! file.open( QIODevice::WriteOnly | QIODevice::Truncate | QIODevice::Text) ) {
-        	kWarning() << "Failed to open layout memory xml file for writing" << file.fileName();
+        	qWarning() << "Failed to open layout memory xml file for writing" << file.fileName();
         	QFAIL("failed");
         }
 
@@ -234,7 +236,6 @@ private Q_SLOTS:
 };
 
 // need kde libs for config-workspace.h used in xkb_rules.cpp
-// need GUI for xkb protocol
-QTEST_KDEMAIN( RulesTest, GUI )
+QTEST_MAIN(RulesTest)
 
 #include "xkb_rules_test.moc"
