@@ -38,6 +38,8 @@ private Q_SLOTS:
     void testCursorTheme();
     void testSplashScreen();
     void testLockScreen();
+    void testWindowSwitcher();
+    void testDesktopSwitcher();
     void testKCMSave();
 
 private:
@@ -149,6 +151,24 @@ void KcmTest::testLockScreen()
     QCOMPARE(cg.readEntry("Theme", QString()), QString("customTestValue"));
 }
 
+void KcmTest::testWindowSwitcher()
+{
+    m_KCMLookandFeel->setWindowSwitcher("customTestValue");
+
+    KConfig config("kwinrc");
+    KConfigGroup cg(&config, "TabBox");
+    QCOMPARE(cg.readEntry("LayoutName", QString()), QStringLiteral("customTestValue"));
+}
+
+void KcmTest::testDesktopSwitcher()
+{
+    m_KCMLookandFeel->setDesktopSwitcher("customTestValue");
+
+    KConfig config("kwinrc");
+    KConfigGroup cg(&config, "TabBox");
+    QCOMPARE(cg.readEntry("DesktopLayout", QString()), QStringLiteral("customTestValue"));
+    QCOMPARE(cg.readEntry("DesktopListLayout", QString()), QStringLiteral("customTestValue"));
+}
 
 void KcmTest::testKCMSave()
 {
@@ -181,6 +201,12 @@ void KcmTest::testKCMSave()
     KConfig lockerConfig("kscreenlockerrc");
     cg = KConfigGroup(&lockerConfig, "Greeter");
     QCOMPARE(cg.readEntry("Theme", QString()), QString("org.kde.test"));
+
+    KConfig kwinConfig("kwinrc");
+    cg = KConfigGroup(&kwinConfig, "TabBox");
+    QCOMPARE(cg.readEntry("LayoutName", QString()), QStringLiteral("testValue"));
+    QCOMPARE(cg.readEntry("DesktopLayout", QString()), QStringLiteral("testDesktopValue"));
+    QCOMPARE(cg.readEntry("DesktopListLayout", QString()), QStringLiteral("testDesktopValue"));
 }
 
 QTEST_MAIN(KcmTest)
